==> milvus-sdk-java-2.5.9-sources.jar: io/milvus/v2/service/vector/response/RunAnalyzerResp.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package io.milvus.v2.service.vector.response;

import lombok.Builder;
import lombok.Data;
import lombok.experimental.SuperBuilder;

import java.util.ArrayList;
import java.util.List;

@Data
@SuperBuilder
public class RunAnalyzerResp {
    @Builder.Default
    List<AnalyzerResult> results = new ArrayList<>();

    @Data
    @SuperBuilder
    public static final class AnalyzerResult {
        @Builder.Default
        List<AnalyzerToken> tokens = new ArrayList<>();
    }

    @Data
    @SuperBuilder
    public static final class AnalyzerToken {
        private String token;
        private Long startOffset;
        private Long endOffset;
        private Long position;
        private Long positionLength;
        private Long hash;
    }
}

==> milvus-sdk-java-2.5.10-sources.jar: io/milvus/v2/service/vector/response/RunAnalyzerResp.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package io.milvus.v2.service.vector.response;

import lombok.Builder;
import lombok.Data;
import lombok.experimental.SuperBuilder;

import java.util.ArrayList;
import java.util.List;

@Data
@SuperBuilder
public class RunAnalyzerResp {
    @Builder.Default
    private List<AnalyzerResult> results = new ArrayList<>();

    @Data
    @SuperBuilder
    public static final class AnalyzerResult {
        @Builder.Default
        private List<AnalyzerToken> tokens = new ArrayList<>();
    }

    @Data
    @SuperBuilder
    public static final class AnalyzerToken {
        private String token;
        private Long startOffset;
        private Long endOffset;
        private Long position;
        private Long positionLength;
        private Long hash;
    }
}
